$.extend({
	
	/**
	 * 判断字符串是为空
	 * @param {Object} message
	 */
	validateEmpty:function(message){
		if(message == null || $.trim(message) == "" || message == undefined){
			return true;
		}
		return false;
	},
	
	alert:function(message){
		if(window.plus){
			plus.nativeUI.alert(message);
		} else{
			mui.alert(message);
		}
	},
	
	toast:function(message){
		if(window.plus){
			plus.nativeUI.toast(message);
		} else{
			mui.toast(message);
		}
	},
	showLoading:function(){
		if(window.plus){
			plus.nativeUI.showWaiting();
		}
	},
	closeLoading:function(){
		if(window.plus){
			plus.nativeUI.closeWaiting();
		}
	},
	/**
	 * ajax get请求
	 * @param {Object} url 请求地址
	 * @param {Object} params 请求参数
	 * @param {Object} success 成功回调
	 * @param {Object} error 错误回调
	 */
	getAjax:function(url, params, header,success, error){
		$.mAjax(url, "get", params, header,success, error);
	},
	
	/**
	 * ajax post请求
	 * @param {Object} url 请求地址
	 * @param {Object} params 请求参数
	 * @param {Object} success 成功回调
	 * @param {Object} error 错误回调
	 */
	postAjax:function(url, params, header, success, error){
		$.mAjax(url, "post", params, header, success, error);
	},
	/**
	 * ajax请求
	 * @param {Object} url 请求地址
	 * @param {Object} params 请求参数
	 * @param {Object} success 成功回调
	 * @param {Object} error 错误回调
	 */
	mAjax:function(url, type, params, header, success, error){
		console.log("请求URL：" + url);
		console.log("请求参数:" + JSON.stringify(params));
		if($.validateEmpty(url)){
			$.toast("url地址不能为空");
			if(typeof error == "function"){
				error("URL_NOT_NULL");
			}
			return false;
		} 
		if(!$.getNetworkInfoStatus()){
			$.toast("未连接网络");
			if(typeof error == "function"){
				error("CONNECTION_NONE");
			}
			return false;
		}
		if(params == null){
			params = {};
		}
		params.token = $.getToken();
		mui.ajax(url, {
			type:type,
			crossDomain:true,	//强制跨域请求
			data:params, //请求参数
			timeout:5000,//请求超时时间(单位：毫秒),如果请求超时会进入error回调
//			dataType:'json',
			headers:header,
			beforeSend:function(){
				console.log("开始发送请求.......");
				$.showLoading();
			},
			complete:function(){
				console.log("请求结束.....");
				$.closeLoading();
			},
			success:function(data){
				console.log(JSON.stringify(data));
				if(data != null){
					if(data.code == 200){
						if(typeof success == "function"){
							success(data);
						} else{
							$.toast(data.message);
						}
					} else if(data.code == 901){
						//未登录
						$.toast(data.message);
					} else if(data.code == 500){
						//全局异常
						$.toast(data.message);
					} else{
						$.toast(data.message);
					}
				}
			},
			error:function(xhr, type, errorThrow){
				console.log("aaaaaaaaaaaaaaaaaa");
				console.log(JSON.stringify(type));
				console.log(JSON.stringify(errorThrow));
				if(type == "timeout"){
					$.toast("请求超时");
					if(typeof error == "function"){
						error("TIME_OUT");
					}
				} else{
					$.closeLoading();
					if(typeof error == "function"){
						error();
					} else{
						$.toast("服务器繁忙,请稍后重试");
					}
				}
			}
		});
	},
	
	//获取Token
	getToken:function(){
		return $.getItem("token");	
	},
	
	//设置token
	setToken:function(tokenValue){
		$.setItem("token", tokenValue);
	},
	
	//本地存储数据
	setItem:function(key, value){
		if(window.plus){
			plus.storage.setItem(key + "", value + "");
		}
	},
	//获取本地存储数据
	getItem:function(key){
		if(window.plus){
			return plus.storage.getItem(key + "");
		}
		return null;
	},
	
	//判断当前是否有网络连接
	getNetworkInfoStatus:function(){
		if(window.plus){
			//获取当前网络类型 
			var status = plus.networkinfo.getCurrentType();
			if(status == plus.networkinfo.CONNECTION_NONE){
				return false;
			} else{
				return true;
			}	
		}
		return false;
	},
	//分页列表获取每页显示条数
	getPageSize:function(){
		return 10;
	},
	/*
	 * 计算开始行
	 * @param {Object} curPage 当前页
	 */
	getStartRow:function(curPage){
		return curPage * $.getPageSize();
	},
	//获取当前版本号
	getVersion:function(){
		if(window.plus){
			plus.runtime.getProperty(plus.runtime.appid, function(info){
				wgtVer = info.version;
				return wgtVer;
			});
		}
		return null;
	},
	/**
	 * 获取系统类型 
	 * android返回字符串:"Android"
	 * ios返回字符串:"iOS"
	 */
	getSystemType:function(){
		if(window.plus){
			return plus.os.name;
		} else{
			return null;
		}
	},
	
	/**
	 * 拨打客服电话
	 */
	dialService:function(){
		if(window.plus){
			plus.device.dial("0546-7077366",true);
		}
	},
	
	
});